<?php
namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Generalsetting;
use App\Models\User;
use App\Models\BankPlan;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Session;

class AdminRegisterController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth:admin');  // Ensure this middleware is applied to protect admin routes
    }

    public function showRegisterForm()
    {
        return view('admin.user.register');  // Pointing to the correct view path
    }

    public function register(Request $request)
    {
        $rules = [
            'email' => 'required|email|unique:users',
            'phone' => 'required',
            'password' => 'required|min:6|confirmed',
            'name' => 'required'
        ];

        $validator = Validator::make($request->all(), $rules);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $gs = Generalsetting::first();
        $subscription = BankPlan::first();

        $user = new User;
        $input = $request->all();
        $input['bank_plan_id'] = $subscription->id;
        $input['plan_end_date'] = Carbon::now()->addDays($subscription->days);
        $input['password'] = bcrypt($request->password);
        $input['account_number'] = $gs->account_no_prefix . date('ydis') . random_int(10, 99);
        $input['email_verified'] = 'Yes';
        $user->fill($input)->save();
        
          // Registration successful, flash success message
    Session::flash('success', 'User registered successfully');

        return redirect()->route('admin.dashboard')->with('success', 'User registered successfully');
    }
}
